@@ -19,8 +19,7 @@
  */
 
 #include "pawn.h"
-
-#include <iostream>
+#include <position.h>
 
 namespace Miniature
 {
@@ -29,8 +28,8 @@ bool MPawn::hasFinishedLoading = false;
 QSvgRenderer MPawn::blackRenderer;
 QSvgRenderer MPawn::whiteRenderer;
 
-MPawn::MPawn(MColour colour, int width, int height)
-: MPiece(colour, PAWN, width, height)
+MPawn::MPawn(MColour colour)
+: MPiece(colour, PAWN)
 {
     loadFromSvgFile();
 }
@@ -38,51 +37,51 @@ MPawn::MPawn(MColour colour, int width, int height)
 MPawn::~MPawn()
 {}
 
-QList<QPoint> MPawn::getPossibleSquares(QPoint point) const
+QList<QPoint> MPawn::getPossibleSquares(const MPosition &pos, const QPoint &origin) const
 {
     QList<QPoint> possibleSquares;
 
     // black
     if (colour == BLACK)
     {
-        if (point.y() + 1 < yDim)
+        if (origin.y() + 1 < pos.getHeight())
         {
-            possibleSquares.append(QPoint(point.x(), point.y() + 1));
-            possibleSquares.append(QPoint(point.x(), point.y() + 2));
-            if (point.x() == 0)
+            possibleSquares.append(QPoint(origin.x(), origin.y() + 1));
+            possibleSquares.append(QPoint(origin.x(), origin.y() + 2));
+            if (origin.x() == 0)
             {
-                possibleSquares.append(QPoint(point.x() + 1, point.y() + 1));
+                possibleSquares.append(QPoint(origin.x() + 1, origin.y() + 1));
             }
-            else if (point.x() == xDim - 1)
+            else if (origin.x() == pos.getWidth() - 1)
             {
-                possibleSquares.append(QPoint(point.x() - 1, point.y() + 1));
+                possibleSquares.append(QPoint(origin.x() - 1, origin.y() + 1));
             }
             else
             {
-                possibleSquares.append(QPoint(point.x() + 1, point.y() + 1));
-                possibleSquares.append(QPoint(point.x() - 1, point.y() + 1));
+                possibleSquares.append(QPoint(origin.x() + 1, origin.y() + 1));
+                possibleSquares.append(QPoint(origin.x() - 1, origin.y() + 1));
             }
         }
     }
     // white
     else
     {
-        if (point.y() - 1 >= 0)
+        if (origin.y() - 1 >= 0)
         {
-            possibleSquares.append(QPoint(point.x(), point.y() - 1));
-            possibleSquares.append(QPoint(point.x(), point.y() - 2));
-            if (point.x() == 0)
+            possibleSquares.append(QPoint(origin.x(), origin.y() - 1));
+            possibleSquares.append(QPoint(origin.x(), origin.y() - 2));
+            if (origin.x() == 0)
             {
-                possibleSquares.append(QPoint(point.x() + 1, point.y() - 1));
+                possibleSquares.append(QPoint(origin.x() + 1, origin.y() - 1));
             }
-            else if (point.x() == xDim - 1)
+            else if (origin.x() == pos.getWidth() - 1)
             {
-                possibleSquares.append(QPoint(point.x() - 1, point.y() - 1));
+                possibleSquares.append(QPoint(origin.x() - 1, origin.y() - 1));
             }
             else
             {
-                possibleSquares.append(QPoint(point.x() + 1, point.y() - 1));
-                possibleSquares.append(QPoint(point.x() - 1, point.y() - 1));
+                possibleSquares.append(QPoint(origin.x() + 1, origin.y() - 1));
+                possibleSquares.append(QPoint(origin.x() - 1, origin.y() - 1));
             }
         }
     }
